aboutsummaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorDan Fandrich <dan@coneharvesters.com>2008-10-19 04:48:15 +0000
committerDan Fandrich <dan@coneharvesters.com>2008-10-19 04:48:15 +0000
commitd51ad518c4c890d69c5d720c52e2d68d3e26cb76 (patch)
tree76842725bf8d7fae2449fc5d976c51a2e135d295 /lib
parent29ba1730cabd948877848e1a59d49ee8e903cbe4 (diff)
Fixed a compiler warning in the CURL_DISABLE_HTTP case
Diffstat (limited to 'lib')
-rw-r--r--lib/transfer.c26
1 files changed, 14 insertions, 12 deletions
diff --git a/lib/transfer.c b/lib/transfer.c
index 796709cd2..abd663ff0 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -111,11 +111,11 @@
#ifndef CURL_DISABLE_HTTP
-static CURLcode readwrite_headers(struct SessionHandle *data,
- struct connectdata *conn,
- struct SingleRequest *k,
- ssize_t *nread,
- bool *stop_reading);
+static CURLcode readwrite_http_headers(struct SessionHandle *data,
+ struct connectdata *conn,
+ struct SingleRequest *k,
+ ssize_t *nread,
+ bool *stop_reading);
#endif /* CURL_DISABLE_HTTP */
/*
@@ -197,6 +197,7 @@ CURLcode Curl_fillreadbuffer(struct connectdata *conn, int bytes, int *nreadp)
return CURLE_OK;
}
+#ifndef CURL_DISABLE_HTTP
/*
* checkhttpprefix()
*
@@ -241,6 +242,7 @@ checkhttpprefix(struct SessionHandle *data,
#endif /* CURL_DOES_CONVERSIONS */
return rc;
}
+#endif /* CURL_DISABLE_HTTP */
/*
* Curl_readrewind() rewinds the read stream. This is typically used for HTTP
@@ -432,7 +434,7 @@ static CURLcode readwrite_data(struct SessionHandle *data,
if(k->header) {
/* we are in parse-the-header-mode */
bool stop_reading = FALSE;
- result = readwrite_headers(data, conn, k, &nread, &stop_reading);
+ result = readwrite_http_headers(data, conn, k, &nread, &stop_reading);
if(result)
return result;
if(stop_reading)
@@ -679,13 +681,13 @@ static CURLcode readwrite_data(struct SessionHandle *data,
#ifndef CURL_DISABLE_HTTP
/*
* Read any header lines from the server and pass them to the client app.
*/
-static CURLcode readwrite_headers(struct SessionHandle *data,
- struct connectdata *conn,
- struct SingleRequest *k,
- ssize_t *nread,
- bool *stop_reading)
+static CURLcode readwrite_http_headers(struct SessionHandle *data,
+ struct connectdata *conn,
+ struct SingleRequest *k,
+ ssize_t *nread,
+ bool *stop_reading)
{
CURLcode result;
@@ -679,13 +681,13 @@ static CURLcode readwrite_data(struct SessionHandle *data,
#ifndef CURL_DISABLE_HTTP
/*
- * Read any header lines from the server and pass them to the client app.
+ * Read any HTTP header lines from the server and pass them to the client app.
*/